@@ -1572,6 +1572,12 @@ class MindsDBParser(Parser):
        'expr LIKE expr',
        'expr NOT_LIKE expr',
        'expr CONCAT expr',
+       'expr VECT_L2 expr',
+       'expr VECT_L1 expr',
+       'expr VECT_INNER expr',
+       'expr VECT_COS expr',
+       'expr VECT_HAMM expr',
+       'expr VECT_JACC expr',
        'expr JSON_GET constant',
        'expr JSON_GET_STR constant',
        'expr NOT_IN expr',
